<?php
/*
Plugin Name:CMEBOSS 會員分級系統(依消費金額)
Plugin URI: https://magiccloud.i234.me/
Description: 專為WOOCOMMERCE 設計的PLUGIN 可依消費金額協助分級會員等級.
Version: 1.0.0
Author: CMEBOSS
Author URI: https://magiccloud.i234.me
License: GPLv2 or later
License URI: https://www.gnu.org/licenses/gpl-2.0.html
Text Domain: woo-event-note
Domain Path: /languages/
*/

function render_custom_level_names_field() {
    $custom_level_names = get_option('custom_level_names');
    $custom_level_names_array = explode("\n", $custom_level_names);
    $count = count($custom_level_names_array);

    for ($i = 1; $i <= 3; $i++) {
        $field_value = isset($custom_level_names_array[$i - 1]) ? trim($custom_level_names_array[$i - 1]) : '';
        echo '<p>';
        echo '<label for="custom_level_name_' . $i . '">Upgrade Amount ' . $i . ': </label>';
        echo '<input type="text" name="custom_level_amount_' . $i . '" value="' . esc_attr(get_option('custom_level_amount_' . $i)) . '" />';
        echo '<label for="custom_level_name_' . $i . '">Upgrade Name ' . $i . ': </label>';
        echo '<input type="text" name="custom_level_name_' . $i . '" value="' . esc_attr($field_value) . '" />';
        echo '</p>';
    }
}

// 註冊設定選項
function register_member_settings() {
    // 註冊設定區域
    add_settings_section(
        'member-settings-section',
        '會員等級設定',
        'render_member_settings_section',
        'member-settings'
    );

    // 註冊升級金額和自訂等級名稱設定欄位
    for ($i = 1; $i <= 3; $i++) {
        add_settings_field(
            'custom_level_amount_' . $i,
            '晉級金額 ' . $i,
            'render_custom_level_amount_field',
            'member-settings',
            'member-settings-section',
            array('level' => $i)
        );
        register_setting('member-settings-group', 'custom_level_amount_' . $i);

        add_settings_field(
            'custom_level_name_' . $i,
            '升級名稱 ' . $i,
            'render_custom_level_name_field',
            'member-settings',
            'member-settings-section',
            array('level' => $i)
        );
        register_setting('member-settings-group', 'custom_level_name_' . $i);
    }
}
add_action('admin_init', 'register_member_settings');

// 渲染升級金額設定欄位
function render_custom_level_amount_field($args) {
    $level = $args['level'];
    $custom_level_amount = get_option('custom_level_amount_' . $level);
    echo '<input type="text" name="custom_level_amount_' . $level . '" value="' . esc_attr($custom_level_amount) . '" />';
}

// 渲染自訂等級名稱設定欄位
function render_custom_level_name_field($args) {
    $level = $args['level'];
    $custom_level_name = get_option('custom_level_name_' . $level);
    echo '<input type="text" name="custom_level_name_' . $level . '" value="' . esc_attr($custom_level_name) . '" />';
}

// 更新會員等級
function update_member_levels() {
    $users = get_users();

    foreach ($users as $user) {
        $user_id = $user->ID;
        $member_total_spent = get_user_meta($user_id, 'member_total_spent', true);
        $custom_level_amounts = array();
        $custom_level_names = array();

        for ($i = 1; $i <= 3; $i++) {
            $custom_level_amounts[$i] = get_option('custom_level_amount_' . $i);
            $custom_level_names[$i] = get_option('custom_level_name_' . $i);
        }

        $member_level = isset($custom_level_names[1]) ? trim($custom_level_names[1]) : 'COOPER';

foreach ($custom_level_amounts as $level => $amount) {
    if ($member_total_spent > $amount) {
        $member_level = isset($custom_level_names[$level]) ? trim($custom_level_names[$level]) : 'COOPER';
    } else {
        break;
    }
}


        update_user_meta($user_id, 'member_level', $member_level);
    }
}

// 添加後台選單頁面
function add_member_settings_page() {
    add_submenu_page(
        'woocommerce',
        '會員等級設定',
        '會員等級設定',
        'manage_options',
        'member-settings',
        'render_member_settings_page'
    );
}
add_action('admin_menu', 'add_member_settings_page');

// 渲染後台選單頁面
function render_member_settings_page() {
    ?>
    <div class="wrap">
        <h1>Member Settings</h1>
        <form action="options.php" method="post">
            <?php
            settings_fields('member-settings-group');
            do_settings_sections('member-settings');
            submit_button();
            ?>
        </form>
    </div>
    <?php

    update_member_levels(); // 在顯示頁面時同步更新會員等級
}

// 計算指定會員的總消費金額
function calculate_total_spent($user_id) {
    $orders = wc_get_orders(array(
        'customer' => $user_id,
        'status'   => array('wc-completed', 'wc-processing') // 設定需要計算的訂單狀態，例如已完成和處理中的訂單
    ));

    $total_spent = 0;

    foreach ($orders as $order) {
        $total_spent += $order->get_total();
    }

    return $total_spent;
}

// 更新所有會員的總消費金額和等級
function update_all_member_data() {
    $users = get_users();

    foreach ($users as $user) {
        $user_id = $user->ID;
        $current_member_level = get_user_meta($user_id, 'member_level', true);
        $current_member_total_spent = get_user_meta($user_id, 'member_total_spent', true);

        if (empty($current_member_level)) {
            update_user_meta($user_id, 'member_level', 'COOPER');
        }

        if (empty($current_member_total_spent)) {
            $total_spent = calculate_total_spent($user_id);
            update_user_meta($user_id, 'member_total_spent', $total_spent);
        }
    }

    update_member_levels(); // 更新會員等級
}
add_action('user_register', 'update_all_member_data');

// 在"我的帐号"页面的控制台中显示会员等级相关信息
function display_member_level_info() {
    $user_id = get_current_user_id();
    $member_level = get_user_meta($user_id, 'member_level', true);
    $member_total_spent = get_user_meta($user_id, 'member_total_spent', true);
    

    echo '<p>會員等級: <b>' . $member_level . '</b>｜ 目前累積消費金額為: <b>'. $member_total_spent . '</b> 元 ｜';

	$next_level_amount = '';
    $custom_level_amounts = array();
    $custom_level_names = array();

    for ($i = 1; $i <= 3; $i++) {
        $custom_level_amounts[$i] = get_option('custom_level_amount_' . $i);
        $custom_level_names[$i] = get_option('custom_level_name_' . $i);
    }

    foreach ($custom_level_amounts as $level => $amount) {
        if ($amount > $member_total_spent) {
            $next_level_amount = $amount - $member_total_spent;
            break;
        }
    }

    if ($next_level_amount) {
        echo '距離升級到下一個等級還需: <b>' . $next_level_amount . '</b> 元</p>';
    }
}
add_action('woocommerce_account_dashboard', 'display_member_level_info');



?>
